@@ -18,10 +18,10 @@ use structopt::StructOpt;
 
 use crate::api;
 use crate::k8s;
+use crate::location::Location;
 use crate::show::{Detailed, Quiet};
 use crate::traits::Show;
 use crate::v0;
-use crate::Location;
 use crate::Output;
 
 use aws::AwsCredentials;
@@ -109,6 +109,13 @@ enum Command {
             visible_alias = "fs"
         )]
         fs_type: Option<v0::VolumeFileSystem>,
+        #[structopt(
+            long,
+            help = "Extra query parameters for create_state API call",
+            parse(try_from_str = parse_params),
+            hidden = true
+        )]
+        params: Vec<(String, String)>,
     },
 
     #[structopt(
@@ -241,7 +248,7 @@ enum Command {
         name: Option<v0::ClusterName>,
 
         #[structopt(
-            help = "Non-interactive cluster registration, automatic defaults apply",
+            help = "Non-interactive cluster unregistration, automatic defaults apply",
             long,
             short = "y",
             alias = "yes",
@@ -681,11 +688,12 @@ impl Cli {
                 clusters,
                 storage_class,
                 fs_type,
+                params,
             } => {
                 let storage_class =
                     v0::StorageClass::new_if_not_default(&name, storage_class, fs_type);
                 statehub
-                    .create_state(name, owner, locations, clusters, storage_class)
+                    .create_state(name, owner, locations, clusters, storage_class, params)
                     .await
             }
             Command::DeleteState { name } => statehub.delete_state(name).await,
@@ -966,6 +974,7 @@ impl StateHub {
         locations: Vec<Location>,
         clusters: Vec<v0::ClusterName>,
         storage_class: Option<v0::StorageClass>,
+        params: Vec<(String, String)>,
     ) -> anyhow::Result<()> {
         let mut locations = vec![locations];
         for name in &clusters {
@@ -980,7 +989,7 @@ impl StateHub {
             allowed_clusters: None,
         };
         self.api
-            .create_state(state)
+            .create_state(state, params)
             .await
             .print(&self.stdout, &self.style, self.json)
     }
@@ -1556,3 +1565,10 @@ impl str::FromStr for Entity {
         }
     }
 }
+
+fn parse_params(text: &str) -> anyhow::Result<(String, String)> {
+    text.split('=')
+        .collect_tuple()
+        .map(|(key, value)| (key.to_string(), value.to_string()))
+        .ok_or_else(|| anyhow::anyhow!("Invalid format: should be key=value"))
+}
