@@ -797,22 +797,35 @@ fn generate_add_location_commands(
 mod tests {
     use super::*;
 
+    fn state(name: impl AsRef<str>) -> v0::State {
+        let name = v0::StateName::from(name.as_ref());
+        v0::State {
+            id: uuid::Uuid::default(),
+            name,
+            created: chrono::Utc::now(),
+            modified: chrono::Utc::now(),
+            storage_class: None,
+            locations: v0::StateLocations::default(),
+            owner: None,
+            provisioning_status: v0::ProvisioningStatus::default(),
+            allowed_clusters: None,
+            condition: v0::Condition::Green,
+        }
+    }
+
     #[test]
     fn generate_add_location_commands() {
         let missing_locations = vec![
+            (state("alfa"), vec![Location::Aws(v0::AwsRegion::UsWest2)]),
             (
-                v0::State::new("alfa"),
-                vec![Location::Aws(v0::AwsRegion::UsWest2)],
-            ),
-            (
-                v0::State::new("bravo"),
+                state("bravo"),
                 vec![
                     Location::Aws(v0::AwsRegion::UsEast1),
                     Location::Azure(v0::AzureRegion::EastUs2),
                 ],
             ),
             (
-                v0::State::new("charlie"),
+                state("charlie"),
                 vec![Location::Aws(v0::AwsRegion::UsWest2)],
             ),
         ]
